.. _acsdestripeplus:

*****************
ACS Destripe Plus
*****************

.. currentmodule:: acstools.acs_destripe_plus

.. automodule:: acstools.acs_destripe_plus
   :members: destripe_plus, crrej_plus


Global Variables
----------------

.. autodata:: acstools.acs_destripe_plus.SUBARRAY_LIST


Version
-------

.. autodata:: acstools.acs_destripe_plus.__version__
.. autodata:: acstools.acs_destripe_plus.__vdate__


Author
------

.. autodata:: acstools.acs_destripe_plus.__author__
